==> tine20-allinone_2020.08.8.tar.bz2: Addressbook/js/Addressbook-lang-nb-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nb\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Firma Kontakt Informasjon"

, "Organisation / Unit"
: "Organisasjon / Enhet"

, "Business Address"
: "Firma Adresse"

, "Email"
: "E-Post"

, "Telephone Work"
: "Telefon Jobb"

, "Telephone Cellphone"
: "Telefon Mobil"

, "Telephone Car"
: "Telefon Bil"

, "Telephone Fax"
: "Telefon Fax"

, "Telephone Page"
: "Telefon Side"

, "URL"
: "URL"

, "Role"
: "Rolle"

, "Room"
: "Rom"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Assistent Telefon"

, "Private Contact Data"
: "Private Kontakt Detaljer"

, "Private Address"
: "Privat Adresse"

, "Email Home"
: "E-Post Hjem"

, "Telephone Home"
: "Telefon Hjem"

, "Telephone Cellphone Private"
: "Telefon Privat Mobil"

, "Telephone Fax Home"
: "Telefon Fax Hjem"

, "URL Home"
: "URL Hjemme"

, "Other Data"
: "Andre Data"

, "Birthday"
: "Bursdag"

, "Job Title"
: "Jobb Tittel"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  ""
 ,""

]
, "Percent"
: ""

, "Description"
: "Beskrivelse"

, "Members"
: ""

, "Type"
: "Type"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  ""
 ,""

]
, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakter"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Land"

, "City"
: "By"

, "Postalcode"
: "Postnummer"

, "Region"
: "Sted"

, "Street"
: "Gate"

, "Street 2"
: "Gate 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Land (privat)"

, "City (private)"
: "By (privat)"

, "Postalcode (private)"
: "Postnummer (privat)"

, "Region (private)"
: "Sted (privat)"

, "Street (private)"
: "Gate (privat)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "E-Post (Privat)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Notat"

, "Last Name"
: "Etternavn"

, "Display Name"
: "Visnings Navn"

, "Full Name"
: "Fullt Navn"

, "First Name"
: "Fornavn"

, "Middle Name"
: "Mellom Navn"

, "Title"
: "Tittel"

, "Suffix"
: "Etternavn"

, "Company"
: "Firma"

, "Unit"
: "Enhet"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Stilling"

, "Salutation"
: "Hilsen"

, "syncBackendIds"
: ""

, "Car phone"
: "Bil Telefon"

, "Mobile"
: "Mobil"

, "Mobile (private)"
: "Mobil (privat)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (privat)"

, "Phone (private)"
: "Telefon (privat)"

, "Pager"
: "Personsøker"

, "Phone"
: "Telefon"

, "Timezone"
: "Tids sone"

, "Web"
: "Internett"

, "URL (private)"
: "URL (privat)"

, "Label"
: ""

, "Lists"
: "Lister"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Kontakt Informasjon"

, "Company Address"
: "Firma Adresse"

, "New Contact"
: "Ny kontakt"

, "ID"
: ""

, "Name"
: "Navn"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Privat"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Overskrifter"

, "List Roles"
: ""

, "Street (Company Address)"
: "Gate (Firma adresse)"

, "Street 2 (Company Address)"
: "Gate 2 (Firma adresse)"

, "City (Company Address)"
: "By (Firma adresse)"

, "Region (Company Address)"
: "Fylke (Firma adresse)"

, "Postal Code (Company Address)"
: "Postnr (Firma adresse)"

, "Country (Company Address)"
: "Land (Firma adresse)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Gate (Privat adresse)"

, "Street 2 (Private Address)"
: "Gate 2 (Privat adresse)"

, "City (Private Address)"
: "By (Privat adresse)"

, "Region (Private Address)"
: "Fylke (Privat adresse)"

, "Postal Code (Private Address)"
: "Postnr (Privat adresse)"

, "Country (Private Address)"
: "Land (Privat adresse)"

, "Company Communication"
: ""

, "Private Communication"
: ""

, "E-Mail"
: "E-Post"

, "E-Mail (private)"
: "E-Post (privat)"

, "Web (private)"
: ""

, "Contacts"
: "Kontakter"

, "Addressbooks"
: ""

, "User Account"
: "Bruker Konto"

, "Quick Search"
: "Hurtigsøk"

, "Postal Code"
: "Post Nummer"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Opprettelses dato"

, "Created By"
: "Opprettet Av"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Skriv en beskrivelse"

, "{0} must be given"
: ""

, "Member of List"
: ""

, "Map"
: ""

, "Company address"
: "Firma Adresse"

, "Private address"
: "Privat Adresse"

, "CardDAV URL"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Personlig Informasjon"

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Alle kontakter"

, "Default Addressbook"
: "Standard Adressebok"

, "The default addressbook for new contacts"
: "Standard adressebok for nye kontakter"

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: "Standard"

, "All Contacts"
: "Alle kontakter"

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Herr"

, "Ms"
: "Fru"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "manage shared addressbooks"
: "organisere delte adressebøker"

, "Create new shared addressbook folders"
: "Opprett nye delte adressebok mapper"

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s's personlige adressebok"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "Internal Contacts"
: "Interne Kontakter"

, "List"
: ""

, "Addressbook"
: ""

, "Contact"
: "Kontakt"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-nb-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nLanguage: nb\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: ""

, "Preferred Address"
: ""

, "Personal Information"
: "Personlig Informasjon"

, "Salutation"
: "Hilsen"

, "Title"
: "Tittel"

, "Short Name"
: ""

, "First Name"
: "Fornavn"

, "Middle Name"
: "Mellom Navn"

, "Last Name"
: "Etternavn"

, "Company"
: "Firma"

, "Unit"
: "Enhet"

, "Display Name"
: "Visnings Navn"

, "Industry, Industries"
: [
  ""
 ,""

]
, "Job Title"
: "Jobb Tittel"

, "Birthday (private)"
: ""

, "Contact Information"
: "Kontakt Informasjon"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefon (privat)"

, "Mobile (private)"
: "Mobil (privat)"

, "Fax (private)"
: "Fax (privat)"

, "E-Mail"
: "E-Post"

, "E-Mail (private)"
: "E-Post (privat)"

, "Web"
: "Internett"

, "Company Address"
: "Firma Adresse"

, "Street"
: "Gate"

, "Street 2"
: "Gate 2"

, "Region"
: "Sted"

, "Postal Code"
: "Post Nummer"

, "City"
: "By"

, "Country"
: "Land"

, "Private Address"
: "Privat Adresse"

, "Description"
: "Beskrivelse"

, "Enter description"
: "Skriv en beskrivelse"

, "Groups"
: ""

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakter"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: ""

, "New Contact"
: "Ny kontakt"

, "Addressbook, Addressbooks"
: [
  ""
 ,""

]
, "ID"
: ""

, "Name"
: "Navn"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Private"
: "Privat"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "Etternavn"

, "Birthday"
: "Bursdag"

, "Job Role"
: "Stilling"

, "Room"
: "Rom"

, "Street (Company Address)"
: "Gate (Firma adresse)"

, "Street 2 (Company Address)"
: "Gate 2 (Firma adresse)"

, "City (Company Address)"
: "By (Firma adresse)"

, "Region (Company Address)"
: "Fylke (Firma adresse)"

, "Postal Code (Company Address)"
: "Postnr (Firma adresse)"

, "Country (Company Address)"
: "Land (Firma adresse)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Gate (Privat adresse)"

, "Street 2 (Private Address)"
: "Gate 2 (Privat adresse)"

, "City (Private Address)"
: "By (Privat adresse)"

, "Region (Private Address)"
: "Fylke (Privat adresse)"

, "Postal Code (Private Address)"
: "Postnr (Privat adresse)"

, "Country (Private Address)"
: "Land (Privat adresse)"

, "Company Communication"
: ""

, "Private Communication"
: ""

, "Web (private)"
: ""

, "Contacts"
: "Kontakter"

, "Addressbooks"
: ""

, "User Account"
: "Bruker Konto"

, "Quick Search"
: "Hurtigsøk"

, "Type"
: "Type"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Opprettelses dato"

, "Created By"
: "Opprettet Av"

, "List, Lists"
: [
  ""
 ,""

]
, "Lists"
: "Lister"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Overskrifter"

, "Full Name"
: "Fullt Navn"

, "Postalcode"
: "Postnummer"

, "Street (private)"
: "Gate (privat)"

, "City (private)"
: "By (privat)"

, "Region (private)"
: "Sted (privat)"

, "Postalcode (private)"
: "Postnummer (privat)"

, "Country (private)"
: "Land (privat)"

, "Email"
: "E-Post"

, "Car phone"
: "Bil Telefon"

, "Pager"
: "Personsøker"

, "Email (private)"
: "E-Post (Privat)"

, "URL (private)"
: "URL (privat)"

, "Note"
: "Notat"

, "Timezone"
: "Tids sone"

, "Geo"
: "Geo"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: "Firma Adresse"

, "Private address"
: "Privat Adresse"

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Alle kontakter"

, "Default Addressbook"
: "Standard Adressebok"

, "The default addressbook for new contacts"
: "Standard adressebok for nye kontakter"

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: "Standard"

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Herr"

, "Ms"
: "Fru"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "%s's personlige adressebok"

, "Business Contact Data"
: "Firma Kontakt Informasjon"

, "Organisation / Unit"
: "Organisasjon / Enhet"

, "Business Address"
: "Firma Adresse"

, "Telephone Work"
: "Telefon Jobb"

, "Telephone Cellphone"
: "Telefon Mobil"

, "Telephone Car"
: "Telefon Bil"

, "Telephone Fax"
: "Telefon Fax"

, "Telephone Page"
: "Telefon Side"

, "URL"
: "URL"

, "Role"
: "Rolle"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Assistent Telefon"

, "Private Contact Data"
: "Private Kontakt Detaljer"

, "Email Home"
: "E-Post Hjem"

, "Telephone Home"
: "Telefon Hjem"

, "Telephone Cellphone Private"
: "Telefon Privat Mobil"

, "Telephone Fax Home"
: "Telefon Fax Hjem"

, "URL Home"
: "URL Hjemme"

, "Other Data"
: "Andre Data"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Interne Kontakter"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "All Contacts"
: "Alle kontakter"

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "organisere delte adressebøker"

, "Create new shared addressbook folders"
: "Opprett nye delte adressebok mapper"

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "Industry"
: ""

, "Contact"
: "Kontakt"

, "Addressbook"
: ""

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
